/**
 * jeelink Platform Plugin for HomeBridge (https://github.com/nfarina/homebridge)
 *
 * Based up on the protocol implementation by: @foxthefox
 * https://github.com/foxthefox/ioBroker.jeelink / https://github.com/foxthefox/ioBroker.jeelink/blob/master/jeelink.js
 *
 * @url https://github.com/gamma/homebridge-jeelink
 * @author Gerry Weißbach
 * @license MIT
 */
/* jslint node: true, laxcomma: true, esversion: 6 */
'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
exports.LaCrosseDTHParser = void 0;
const LaCrosseDTHAccessory_1 = require("../accessories/LaCrosseDTHAccessory");
const LaCrosseDTTAccessory_1 = require("../accessories/LaCrosseDTTAccessory");
/*
JeeLinkAccessory = require('../accessory').default(homebridge);
FakeGatoHistoryService = require("fakegato-history")(homebridge);
*/
class LaCrosseDTHParser {
    constructor(platform) {
        this.platform = platform;
        this.Service = this.platform.api.hap.Service;
        this.Characteristic = this.platform.api.hap.Characteristic;
        this.log = this.platform.log;
        this.type = 'LaCrosse Temperature Sensor';
    }
    parseValue(input) {
        const tmp = ('' + input).split(' ');
        // if not OK return
        if (tmp[0] !== 'OK') {
            return;
        }
        // Wenn ein Datensatz sauber gelesen wurde
        if (tmp[1] !== '9') {
            return;
        }
        // Protocol is required.
        if (tmp.length !== 7) {
            return;
        }
        // Für jeden Datensatz mit dem fixen Eintrag 9
        const tmpp = tmp.splice(2, 6); // es werden die vorderen Blöcke (0,1,2) entfernt
        this.log.debug('splice       : ' + tmpp);
        const buf = Buffer.from(tmpp);
        const temp = ((((buf.readUInt8(2)) * 256) + (buf.readUInt8(3)) - 1000) / 10);
        const data = {
            id: (buf.readUInt8(0)),
            type: ((buf.readUInt8(1) & 0x70) >> 4),
            sensor_type: (buf.readUInt8(1) & 0x3),
            temperature: temp,
            temperature2: 0,
            newBat: 0,
            lowBat: 0,
            humidity: 0,
            absHumidity: 0,
            dewPoint: 0,
        };
        const device = this.getOrCreateDevice(data.id, data.sensor_type);
        if (device === null) {
            this.log.debug('Device not configured with with ID: ' + data.id);
            return;
        }
        this.log.debug('Sensor ID    : ' + data.id);
        this.log.debug('Type         : ' + data.type);
        this.log.debug('Sensor Type  : ' + data.sensor_type);
        this.log.debug('Temperatur   : ' + data.temperature);
        if (data.sensor_type === 1) {
            data.newBat = ((buf.readUInt8(1) & 0x80) >> 7); // wenn "100000xx" dann NewBatt # xx = SensorType 1 oder 2
            data.lowBat = ((buf.readUInt8(4) & 0x80) >> 7); // Hier muss noch "incl. WeakBatteryFlag" ausgewertet 
            this.log.debug('NewBattery   : ' + data.newBat);
            this.log.debug('LowBattery   : ' + data.lowBat);
        }
        device.updateData(data, buf);
    }
    getOrCreateDevice(id, type) {
        // Check if the model exists in the current instance
        switch (type) {
            case 1:
                return this.platform.createAccessory(LaCrosseDTHAccessory_1.LaCrosseDTHAccessory, id, type);
            case 2:
                return this.platform.createAccessory(LaCrosseDTTAccessory_1.LaCrosseDTTAccessory, id, type);
            default:
                this.log.error('Unknown sensor type: ' + type);
        }
        // If the device is not defined, we're not in scan mode and do not know the device
        return null;
    }
    configure(accessory) {
        const returnDevice = new LaCrosseDTHAccessory_1.LaCrosseDTHAccessory(this.platform, accessory);
        this.platform.log.info('Done configuring LaCrosseDTH Accessory', accessory.displayName);
        return returnDevice;
    }
}
exports.LaCrosseDTHParser = LaCrosseDTHParser;
//# sourceMappingURL=LaCrosseDTH.js.map